# Welcome to gtlparser


[![image](https://img.shields.io/pypi/v/gtlparser.svg)](https://pypi.python.org/pypi/gtlparser)


**Python Boilerplate contains all the boilerplate you need to create a Python package.**


-   Free software: MIT License
-   Documentation: <https://GGweelplay.github.io/gtlparser>


## Features

-   TODO

## Usage
```python
import gtlparser
```